
#of_container {
	width: auto;
}

#of_container #header {
	height: 70px;
	background:#f1f1f1;
	border: 1px solid #E7E7E7;

	-webkit-border-radius: 6px 6px 0 0;
	-moz-border-radius: 6px 6px 0 0;
	border-radius: 6px 6px 0 0;
	
	background-image: -ms-linear-gradient(top,#f9f9f9,#ececec);
	background-image: -moz-linear-gradient(top,#f9f9f9,#ececec);
	background-image: -o-linear-gradient(top,#f9f9f9,#ececec);
	background-image: -webkit-gradient(linear,left top,left bottom,from(#f9f9f9),to(#ececec));
	background-image: -webkit-linear-gradient(top,#F9F9F9,rgba(134, 132, 118, 0.38));
	background-image: linear-gradient(top,#f9f9f9,#ececec);
	
	-moz-box-shadow: inset 0 1px 0 #fff;
	-webkit-box-shadow: inset 0 1px 0 #fff;
	box-shadow: inset 0 1px 0 #fff;
}

#of_container #of-nav {
	display: none;
}

#of_container #content {
	width: 100%;
	padding: 0;
}

#of_container .group {
	padding: 0 25px;
}

#of_container .group h2 {
	display:block;
}

#of_container #expand_options {
	display: none;	
}

.wrap h2, .subtitle {
	text-shadow: none;
}

#of_container .controls .of-color-alpha {
	width: 340px;
	text-align: center;	
}

div.colorpicker {
float: left;
clear: both;
}


#of_container p.shrk_font_preview {
	display: block;
	border: 1px dotted lightgray;
	float: left;
	padding: 10px;
	font-size: 10pt;
	width: 318px;
	height: auto;
	margin: 0 0 10px 0;
	line-height: 1.2;
}

#cpt_info_box {
	display: none;
}

#sectionpicker {
	overflow: hidden;	
	box-sizing: border-box;
	margin-top: 20px;
}

.section-sortable-wrapper {
	overflow: hidden;	
	width: 49%;
	float: left;
}

.section-sortable-wrapper h5 {
	font-size: 100%;	
	margin: 0 10px -10px 0;
	text-align: center;
	color: #d3d3d3;

}

.sectionpicker .ui-sortable {
	border: 1px solid #d3d3d3;
	min-height: 100px;
}

.sectionpicker .sectionpicker-msg {
	width: 100%;
	margin-bottom: 1em;
	text-decoration: underline;
	text-align: center;
}

.sectionpicker .section-sortable-wrapper:nth-child(2n) {
	margin-right: 2%;
}

.sectionpicker li {
	overflow: hidden;
	cursor: move;
	transition: background-color 0.1s, color 0.1s;
}	

.sectionpicker li.newitem {
	background-color: #278ab7;
	color: #eee;
}

.sectionpicker li .helper-text {
	display: none;
}

.sectionpicker li.newitem .helper-text {
	display: inline-block;
}

.sectionpicker li i {
	transition: background-color 0.1s, color 0.1s;	
}

.sectionpicker li.newitem i,
.sectionpicker li.newitem a{
	color: #eee;
}

.sectionpicker li a {
	text-decoration: none;
}


.sectionpicker li .iconlinks {
	float:right;
	margin-left: 5px;
}

.sectionpicker .helper-text {
	float: right;
	display: inline-block;
	font-size: 80%;
	margin-left: 30px;
	text-decoration: underline;
}

.sectionpicker .shrk-new-section-button {
	float: right;
}

.sectionpicker .spinner {
	margin-top: 5px;
}

.ui-state-default {
	border: 1px solid #d3d3d3;
	background-color: #e6e6e6;
	font-weight: normal;
	color: #555555;
}

.ui-state-default:hover {
	background-color: #D6D6D6;
}

.ui-state-highlight {
	border: 1px dashed #DFDFDF;
	background-color: #F1F1F1;
}

#section-sortable1 li, #section-sortable2 li {
	margin: 6px 6px;
	padding: 5px;
	font-size: 1.2em;
	width: auto;
}

.op-upload-wrap .screenshot .of-option-image {
	width: 100%;
	margin: 10px 0px;
}

/* Portfolio post type */

.column-imagepfl .gallery_items_wrap {
	margin-top: -3px;
}

.column-imagepfl .gallery_items_wrap img {
	border: 1px solid #ccc;
	height: 45px;
	width: 45px;
	float: left;
	margin: 0px 2px 2px 0px;
}

.column-imagepfl .gallery_items_wrap .post-thumbnail img{
	border: 1px solid red;
}

.column-imagepfl {
	width: 20%;
}

.column-type {
	width: 15%;
}

.postbox .section-gallery_items .gallery_items_wrap li {
	overflow: hidden;	
}

.postbox .section-gallery_items .gallery_items_wrap li {
	border: 1px solid #ccc;
	margin: 0px 5px 5px 0px;
	display: inline-block;
	line-height: 0em;
}
.postbox .section-gallery_items .gallery_items_wrap li img {
	width: 100px;
	height: 100px;
}

.postbox .postpreview-iframe {
	width: 100%;
	min-height: 400px;
}

.wpb_edit_form_elements .styled_preview_block {
	width: 100%;
}

.wpb_edit_form_elements .styled_preview_block iframe {
	width: 100%;
	height: 150px;
	/* position: absolute; */
	border: 1px solid #ccc
}

.wpb_edit_form_elements .styled_preview_block input {
	display: none;
}

.wpb_edit_form_elements .icon_picker_block {
	border: 1px solid #BEBEBE;
}

.wpb_edit_form_elements .icon_picker_block ul {
	height: 180px;
	margin: 0;
	overflow: auto;
	
}

.wpb_edit_form_elements .icon_picker_block input {
	display: none;
}	

.wpb_edit_form_elements .icon_picker_block ul li {
	border: 1px solid #ddd;
	color: #ccc;
	text-align: center;
	padding: 10px 0;
	width: 40px;
	min-height: 25px;
	float: left;
	cursor: pointer;
	font-size: 26px;
	margin: 3px 4px;
}

.wpb_edit_form_elements .icon_picker_block ul li:hover {
	border: 1px solid #000;
	color: #000;
}

.wpb_edit_form_elements .icon_picker_block ul li.selected {
	border: 1px solid #6B6B6B;
	color: #6B6B6B;
}

.vc_element-icon.icon-wpb-shrk { 
	background-image: url('../images/vc-icon-50x50.png');
	width: 32px;
	height: 32px;
	background-size: cover;
}

.vc_element-icon.icon-woo-shrk { 
	background-image: url('../images/woo-100x100.png');
	width: 32px;
	height: 32px;
	background-size: cover;
}

.vc_element-icon.icon-woo-slider-shrk { 
	background-image: url('../images/woo-slider-100x100.png');
	width: 32px;
	height: 32px;
	background-size: cover;
}

.wpb_edit_form_elements .text_slides_block .text_slides .text_slide_field {
	padding-right: 50px;
}

.wpb_edit_form_elements .text_slides_block .text_slides li {
	position: relative;
}

.wpb_edit_form_elements .text_slides_block .text_slides li i {
	font-size: 18px;
	line-height: 32px;
	width: 32px;
	text-align: center;
	color: #aaa;
	position: absolute;
	top: 0px;
	right: 0px;
}

.wpb_edit_form_elements .text_slides_block .text_slides li i:nth-child(2n) {
	right: 30px;	
}

.wpb_edit_form_elements .text_slides_block .text_slides li i.remove {

}

.wpb_edit_form_elements .text_slides_block .text_slides li i.reorder {
	cursor: n-resize;
}

.wpb_edit_form_elements ul.icons {
    text-indent: 0;
    margin-left: 0;
}

/* Custom view vertically align text */

.wpb_content_element > .wpb_element_wrapper .wpb_element_title.vertical-center > i.vc_element-icon {
	float: none;
	display: inline-block;
	vertical-align: middle;
}
.wpb_content_element > .wpb_element_wrapper .wpb_element_title.vertical-center > span {
	vertical-align: middle;	
}

.wpb_shrk_slabtext .text_rows {
	overflow: hidden;
}
 
/* Meta boxes */
.postbox .shrk-separator {
	margin-top: 1em;
}

.shrk-input.of-color-alpha {
	padding-left: 3px;
	text-align: center;
}

.postbox .inside .section {
	margin-bottom: 24px;
	padding-bottom: 10px;
	display: table;
	width: 100%;
	box-sizing: border-box;
}

.postbox .inside .section.section-separator {
	border-bottom: 0;
}
.postbox .section .metabox_table {
	display: table-row;
	width: 100%;
	box-sizing: border-box;
}

.postbox .section .metabox_table > * {
	vertical-align: middle;
	box-sizing: border-box;
}

.postbox .section .metabox_table .heading {
	display: table-cell;
	padding-right: 10px;
	width: 30%;
}

.postbox .section .metabox_table .heading h4 {
	margin: 0px 0;
	
}	

.postbox .section .metabox_table .option {
	display: table-cell;
	width: 32%;
}

.postbox .section .metabox_table .description {
	display: table-cell;
	padding-left: 10px;
	width: 30%;
}

.postbox .section .metabox_table .option .of-radio {
	margin: 0 5px 5px 0;
}

.postbox .section .metabox_table .option .op-upload-wrap .of-input {
	width: 100%;
	box-sizing: border-box;
}

.postbox .section .metabox_table .option .op-upload-wrap .upload_button_div .button {
	margin: 5px 5px 10px 0;
}

.postbox .section .metabox_table .option .op-upload-wrap .screenshot,
.postbox .section .metabox_table .option .op-upload-wrap .video_preview {
	border: 1px solid #ccc;
}

/* in side context */
#side-sortables .section .metabox_table {
	display: block;
}

#side-sortables .section .metabox_table > .heading,
#side-sortables .section .metabox_table > .option,
#side-sortables .section .metabox_table > .description {
	display: block;
	width: 100%;
}

#side-sortables .section .metabox_table > .heading {
	margin: 1em 0;
}

#side-sortables .section .metabox_table > .description {
	padding: 0.2em 0 0 0;
	opacity: 0.7;
}

#side-sortables .section {
	margin-bottom: 0;
}

.postbox .section .metabox_table .option .of-color-alpha,
.postbox .section .metabox_table .option .wp-color-result {
	margin:0;
}

.postbox .section .metabox_table .option .range-input-container .range_value,
.postbox .section .metabox_table .option .range-input-container .range_preview {
	clear: both;
	float:left;
	text-align: center;
	color: #777;
}

.postbox .section .metabox_table .description .default-value {
	color: #AAA;
	font-style: italic;
}

/* sectionpicker */

.section-sectionspicker .metabox_table {
	
}

.section-sectionspicker .heading {
	display: block !important;
	padding-right: 10px;
	width: 30%;
	float:left;
	margin-top: 20px;
}

.section-sectionspicker .option {
	display: block !important;
	float:right;
	width: 70% !important;
}

.section-sectionspicker .description {
	display: block !important;
	padding-left: 0px !important;
	padding-right: 30px;
	width: 30% !important;
	float: left;
	position: absolute;
	margin-top: 40px;
}

/* textarea editor */
.postbox .section-textarea_editor .metabox_table .heading {
	width: 10%;
 	min-width: 80px;
}

.postbox .section-textarea_editor .metabox_table .option {
	width: 90%;
}

.postbox .section-textarea_editor .metabox_table .description {
	display: none;
}

.nav-menus-php .mega-menu-checkbox { 
	color: red;
	opacity: 0;
	visibility: hidden;
	transition: 
		color 0.1s linear 0.1s, 
		opacity 0.2s linear 1s,
		visibility 0s linear 1.2s;
	
}
.nav-menus-php .menu-item-depth-0 .mega-menu-checkbox { 
	color: initial;
	opacity: 1;
	visibility: visible;
	transition-delay: 0s;
}

/* redux small tweaks */
.admin-color-fresh .redux-sidebar .redux-group-menu li.activeChild.hasSubSections:not(.empty_section) a {
	background-color: #23282D;
	text-shadow: none;
}

.admin-color-fresh .redux-sidebar .redux-group-menu li.activeChild.hasSubSections:not(.empty_section) a:hover {
	color: #1e8cbe;
	background: #0d0e10;
}

#redux-header .rAds {
	visibility: hidden;
}

.redux-container #redux-header {
	background-image: url('../images/redux_head_bg.jpg');
	background-position: 50% 50%;
	background-size: cover;
	background-repeat: no-repeat;
}

.redux-sidebar [id='10_section_group_li_a'] i.el-photo {
	transform: rotate(180deg); /* Rotate photo icon from elusive icons */
}

.redux-field.wbc_importer .theme-browser .theme.active .theme-actions, 
.redux-field.wbc_importer .theme-browser .theme .theme-actions {
    position: absolute;
    top: auto;
    bottom: 0;
    right: 0;
    transform: none;
}

/* Hide pagesections related redux options when pt not registered */
.require-pagesections-posttype {
	display: none;
}

.pagesections-enabled .require-pagesections-posttype {
	display: block;
}

.pagesections-enabled tr.require-pagesections-posttype {
	display: table-row;
}

/* Minor WooCommerce styles */
#woocommerce-coupon-data ul.wc-tabs li.shrk-product-videos_options a::before, 
#woocommerce-product-data ul.wc-tabs li.shrk-product-videos_options a::before, 
.woocommerce ul.wc-tabs li.shrk-product-videos_options a::before {
	content: "\f236";
}

/* woocommerce styles step over redux styles... */
.redux-main .form-table-section-indented {
	width: 95%;
	margin-left: 5% !important;
}